@@ -13,7 +13,6 @@ def gather(hub, raw):
     """
     ret = {}
     for imp in raw:
-        ret[imp] = {}
         for sec in hub.config.CONFIG_SECTIONS:
             if sec not in raw[imp]:
                 continue
@@ -22,5 +21,8 @@ def gather(hub, raw):
                 if osvar is not None:
                     val = hub.config.os.system.collect(osvar)
                     if val is not None:
-                        ret[imp][key] = val
+                        src = raw[imp][sec][key].get("source", imp)
+                        if src not in ret:
+                            ret[src] = {}
+                        ret[src][key] = val
     return ret
